@@ -29,7 +29,7 @@ namespace pinyin{
 
 ChewingLargeTable2::ChewingLargeTable2() {
     /* create in-memory db. */
-    m_db = new GrassDB;
+    m_db = new ProtoTreeDB;
     assert(m_db->open("-", BasicDB::OREADER|BasicDB::OWRITER|BasicDB::OCREATE));
 
     m_entries = NULL;
@@ -71,7 +71,7 @@ bool ChewingLargeTable2::load_db(const char * filename) {
     init_entries();
 
     /* create in-memory db. */
-    m_db = new GrassDB;
+    m_db = new ProtoTreeDB;
 
     if (!m_db->open("-", BasicDB::OREADER|BasicDB::OWRITER|BasicDB::OCREATE))
         return false;
