@@ -20,7 +20,7 @@
 
 #include "phrase_large_table3.h"
 #include <kchashdb.h>
-#include <kcprotodb.h>
+#include <kccachedb.h>
 #include "kyotodb_utils.h"
 
 
@@ -80,6 +80,10 @@ bool PhraseLargeTable3::load_db(const char * filename) {
     if (!m_db->open("-", BasicDB::OREADER|BasicDB::OWRITER|BasicDB::OCREATE))
         return false;
 
+    if (!m_db->load_snapshot(filename, NULL))
+        return false;
+
+#if 0
     /* load db into memory. */
     BasicDB * tmp_db = new TreeDB;
     if (!tmp_db->open(filename, BasicDB::OREADER))
@@ -90,6 +94,7 @@ bool PhraseLargeTable3::load_db(const char * filename) {
 
     tmp_db->close();
     delete tmp_db;
+#endif
 
     return true;
 }
@@ -99,6 +104,10 @@ bool PhraseLargeTable3::store_db(const char * new_filename){
     if ( ret != 0 && errno != ENOENT)
         return false;
 
+    if (!m_db->dump_snapshot(new_filename, NULL))
+        return false;
+
+#if 0
     BasicDB * tmp_db = new TreeDB;
     if (!tmp_db->open(new_filename, BasicDB::OWRITER|BasicDB::OCREATE))
         return false;
@@ -109,6 +118,7 @@ bool PhraseLargeTable3::store_db(const char * new_filename){
     tmp_db->synchronize();
     tmp_db->close();
     delete tmp_db;
+#endif
 
     return true;
 }
