@@ -1007,9 +1007,10 @@ bool zhuyin_parse_full_pinyin(zhuyin_instance_t * instance,
     /* disable the pinyin correction options. */
     options &= ~PINYIN_CORRECT_ALL;
 
+    gint16 distance = 0;
     int pinyin_len = strlen(onepinyin);
     bool retval = context->m_full_pinyin_parser->parse_one_key
-        (options, *onekey, onepinyin, pinyin_len);
+        (options, *onekey, distance, onepinyin, pinyin_len);
     return retval;
 }
 
@@ -1047,9 +1048,10 @@ bool zhuyin_parse_chewing(zhuyin_instance_t * instance,
     zhuyin_context_t * & context = instance->m_context;
     zhuyin_option_t options = context->m_options;
 
+    gint16 distance = 0;
     int chewing_len = strlen(onechewing);
     bool retval = context->m_chewing_parser->parse_one_key
-        (options, *onekey, onechewing, chewing_len );
+        (options, *onekey, distance, onechewing, chewing_len);
     return retval;
 }
 
@@ -1944,6 +1946,28 @@ bool zhuyin_get_zhuyin_key_rest_length(zhuyin_instance_t * instance,
     return true;
 }
 
+/* find the first zero ChewingKey "'". */
+static size_t _compute_zero_start(PhoneticKeyMatrix & matrix, size_t offset) {
+    ChewingKey key; ChewingKeyRest key_rest;
+    const ChewingKey zero_key;
+
+    ssize_t index = offset - 1;
+    for (; index > 0; --index) {
+        const size_t size = matrix.get_column_size(index);
+
+        if (1 != size)
+            break;
+
+        matrix.get_item(index, 0, key, key_rest);
+        if (zero_key == key)
+            offset = index;
+        else
+            break;
+    }
+
+    return offset;
+}
+
 /* when lookup offset:
    get the previous non-zero ChewingKey. */
 bool zhuyin_get_zhuyin_offset(zhuyin_instance_t * instance,
@@ -1960,6 +1984,7 @@ bool zhuyin_get_zhuyin_offset(zhuyin_instance_t * instance,
             break;
     }
 
+    offset = _compute_zero_start(matrix, offset);
     _check_offset(matrix, offset);
 
     *poffset = offset;
@@ -1991,6 +2016,7 @@ bool zhuyin_get_left_zhuyin_offset(zhuyin_instance_t * instance,
             break;
     }
 
+    offset = _compute_zero_start(matrix, offset);
     _check_offset(matrix, left);
 
     *pleft = left;
@@ -2007,6 +2033,7 @@ bool zhuyin_get_right_zhuyin_offset(zhuyin_instance_t * instance,
     size_t right = offset;
 
     ChewingKey key; ChewingKeyRest key_rest;
+    const ChewingKey zero_key;
     for (size_t index = right; index < matrix.size() - 1; ++index) {
         const size_t size = matrix.get_column_size(index);
 
@@ -2014,7 +2041,10 @@ bool zhuyin_get_right_zhuyin_offset(zhuyin_instance_t * instance,
             break;
 
         matrix.get_item(index, 0, key, key_rest);
-        break;
+        if (zero_key == key)
+            right = index + 1;
+        else
+            break;
     }
 
     if (0 == matrix.get_column_size(right))
